@@ -76,6 +76,6 @@ def get(environ, start_response):
     except StoreMethodNotImplemented:
         raise HTTP400('Search system not implemented')
     except StoreError, exc:
-        raise HTTP400('Error while handling search: %s' % exc)
+        raise HTTP400('Error while processing search: %s' % exc)
 
     return send_tiddlers(environ, start_response, tiddlers=candidate_tiddlers)
